# Installation

## Stable release

To install `analphipy`, run this command in your terminal:

```bash
pip install analphipy
```

or

```bash
conda install -c conda-forge analphipy
```

This is the preferred method to install analphipy, as it will always install the
most recent stable release.

## From sources

See [](./contributing) for details on installing from source.
